@@ -5,7 +5,6 @@ import (
 	"os"
 	"strings"
 
-	"github.com/lmorg/murex/lang/tty"
 	"github.com/lmorg/murex/utils/consts"
 	"github.com/lmorg/murex/utils/home"
 )
@@ -44,7 +43,7 @@ func validateProfilePath(envvar, defaultFileName string) string {
 
 	fi, err := os.Stat(path)
 	if err != nil {
-		fmt.Fprintf(tty.Stderr,
+		fmt.Fprintf(os.Stderr,
 			"Override path specified in %s does not exist: '%s'!\n  Assuming this is intentional, a new file will be created.\n",
 			envvar, path)
 		return path
@@ -66,14 +65,14 @@ func ModulePath() string {
 
 	fi, err := os.Stat(path)
 	if err != nil {
-		fmt.Fprintf(tty.Stderr,
+		fmt.Fprintf(os.Stderr,
 			"Override path specified in %s does not exist: '%s'!\n  Assuming this is intentional, a new directory will be created.\n",
 			ModuleEnvVar, path)
 		return addTrailingSlash(path)
 	}
 
 	if !fi.IsDir() {
-		fmt.Fprintf(tty.Stderr,
+		fmt.Fprintf(os.Stderr,
 			"Override path specified in %s is a file, directory expected: '%s'!\n  Falling back to default path.\n",
 			ModuleEnvVar, path)
 		return home.MyDir + consts.PathSlash + moduleDirName
