@@ -23,6 +23,13 @@ export default sidebar({
       children: "structure",
       collapsible: true,
     },
+    {
+      text: "Integrations",
+      icon: "puzzle-piece",
+      prefix: "integrations/",
+      children: "structure",
+      collapsible: true,
+    },
     {
       text: "Operators And Tokens",
       icon: "equals",
